@@ -277,13 +277,12 @@ meaning there is no limit. The default settings are::
         'prefetch_size': 0,
     }
 """
-from __future__ import unicode_literals
+
 
 import copy
 import logging
 import logging.config
 import os
-import uuid
 
 import pkg_resources
 import toml
@@ -296,8 +295,8 @@ _log = logging.getLogger(__name__)
 _fedora_version = pkg_resources.get_distribution("fedora_messaging").version
 _pika_version = pkg_resources.get_distribution("pika").version
 
-# A default, auto-deleted queue for consumers
-_default_queue_name = str(uuid.uuid4())
+# By default, use a server-generated queue name
+_default_queue_name = ""
 
 #: The default configuration settings for fedora-messaging. This should not be
 #: modified and should be copied with :func:`copy.deepcopy`.
@@ -330,7 +329,7 @@ DEFAULTS = dict(
         _default_queue_name: {
             "durable": False,
             "auto_delete": True,
-            "exclusive": False,
+            "exclusive": True,
             "arguments": {},
         }
     },
@@ -383,7 +382,7 @@ def validate_bindings(bindings):
 
     for binding in bindings:
         missing_keys = []
-        for key in ("queue", "exchange", "routing_keys"):
+        for key in ("exchange", "routing_keys"):
             if key not in binding:
                 missing_keys.append(key)
         if missing_keys:
@@ -447,7 +446,7 @@ def validate_client_properties(props):
         # Don't let users override these as they identify this library in AMQP
         if props[key] != DEFAULTS["client_properties"][key]:
             raise exceptions.ConfigurationException(
-                '"{}" is a reserved keyword in client_properties'.format(key)
+                f'"{key}" is a reserved keyword in client_properties'
             )
 
 
@@ -459,12 +458,12 @@ class LazyConfig(dict):
     def __getitem__(self, *args, **kw):
         if not self.loaded:
             self.load_config()
-        return super(LazyConfig, self).__getitem__(*args, **kw)
+        return super().__getitem__(*args, **kw)
 
     def get(self, *args, **kw):
         if not self.loaded:
             self.load_config()
-        return super(LazyConfig, self).get(*args, **kw)
+        return super().get(*args, **kw)
 
     def pop(self, *args, **kw):
         raise exceptions.ConfigurationException("Configuration keys cannot be removed!")
@@ -472,12 +471,12 @@ class LazyConfig(dict):
     def copy(self, *args, **kw):
         if not self.loaded:
             self.load_config()
-        return super(LazyConfig, self).copy(*args, **kw)
+        return super().copy(*args, **kw)
 
     def update(self, *args, **kw):
         if not self.loaded:
             self.load_config()
-        return super(LazyConfig, self).update(*args, **kw)
+        return super().update(*args, **kw)
 
     def setup_logging(self):
         if not self.loaded:
@@ -521,7 +520,7 @@ class LazyConfig(dict):
                 config_path = "/etc/fedora-messaging/config.toml"
 
         if os.path.exists(config_path):
-            _log.info("Loading configuration from {}".format(config_path))
+            _log.info(f"Loading configuration from {config_path}")
             with open(config_path) as fd:
                 try:
                     file_config = toml.load(fd)
@@ -533,7 +532,7 @@ class LazyConfig(dict):
                     )
                     raise exceptions.ConfigurationException(msg)
         else:
-            _log.info("The configuration file, {}, does not exist.".format(config_path))
+            _log.info(f"The configuration file, {config_path}, does not exist.")
 
         self.update(config)
         self._validate()
