@@ -23,13 +23,9 @@ If you find yourself implementing a pattern over and over in your test code,
 consider contributing it here!
 """
 
-from contextlib import contextmanager
 import inspect
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+from contextlib import contextmanager
+from unittest import mock
 
 
 @contextmanager
