@@ -16,9 +16,7 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 """Unit tests for :module:`fedora_messaging.config`."""
 
-import unittest
-
-import mock
+from unittest import mock, TestCase
 
 from fedora_messaging import config as msg_config
 from fedora_messaging.exceptions import ConfigurationException
@@ -90,11 +88,11 @@ partial_config = 'publish_exchange = "special_exchange"'
 malformed_config = 'publish_exchange = "special_exchange'  # missing close quote
 
 
-class TestObj(object):
-    """This exists purely to make __repr__ the same on Python 2 and 3."""
+class TestObj:
+    pass
 
 
-class ValidateBindingsTests(unittest.TestCase):
+class ValidateBindingsTests(TestCase):
     """Unit tests for :func:`fedora_messaging.config.validate_bindings`."""
 
     def test_valid(self):
@@ -125,7 +123,6 @@ class ValidateBindingsTests(unittest.TestCase):
             "Configuration error: a binding is missing the following keys",
             str(cm.exception),
         )
-        self.assertIn("queue", str(cm.exception))
         self.assertIn("exchange", str(cm.exception))
         self.assertIn("routing_keys", str(cm.exception))
 
@@ -141,7 +138,7 @@ class ValidateBindingsTests(unittest.TestCase):
         )
 
 
-class ValidateQueuesTests(unittest.TestCase):
+class ValidateQueuesTests(TestCase):
     """Unit tests for :func:`fedora_messaging.config.validate_queues`."""
 
     def test_valid(self):
@@ -189,7 +186,7 @@ class ValidateQueuesTests(unittest.TestCase):
         self.assertIn("arguments", str(cm.exception))
 
 
-class LoadTests(unittest.TestCase):
+class LoadTests(TestCase):
     """Unit tests for :func:`fedora_messaging.config.load`."""
 
     def test_deep_copy(self):
