@@ -24,121 +24,25 @@ fedmsg-migration-tools for a use case.
 See https://twistedmatrix.com/documents/current/core/howto/application.html
 """
 
-from __future__ import absolute_import, unicode_literals
-import locale
+
 import logging
 import ssl
-import warnings
+import sys
 
-from pika import SSLOptions
 import pika
-import six
+from pika import SSLOptions
 from twisted.application import service
-from twisted.application.internet import TCPClient, SSLClient
-from twisted.internet import ssl as twisted_ssl, defer
+from twisted.application.internet import SSLClient, TCPClient
+from twisted.internet import defer
+from twisted.internet import ssl as twisted_ssl
 
 from .. import config, exceptions
-from .factory import FedoraMessagingFactory, FedoraMessagingFactoryV2
+from .factory import FedoraMessagingFactoryV2
 
 
 _log = logging.getLogger(__name__)
 
 
-class FedoraMessagingService(service.MultiService):
-    """
-    A Twisted service to connect to the Fedora Messaging broker.
-
-    Args:
-        on_message (callable|None): Callback that will be passed each
-            incoming messages. If None, no message consuming is setup.
-        amqp_url (str): URL to use for the AMQP server.
-        exchanges (list of dicts): List of exchanges to declare at the start of
-            every connection. Each dictionary is passed to
-            :meth:`pika.channel.Channel.exchange_declare` as keyword arguments,
-            so any parameter to that method is a valid key.
-        queues (list of dicts): List of queues to declare at the start of every
-            connection. Each dictionary is passed to
-            :meth:`pika.channel.Channel.queue_declare` as keyword arguments,
-            so any parameter to that method is a valid key.
-        bindings (list of dicts): A list of bindings to be created between
-            queues and exchanges. Each dictionary is passed to
-            :meth:`pika.channel.Channel.queue_bind`. The "queue" and "exchange" keys
-            are required.
-        consumers (dict): A dictionary where each key is a queue name and the value
-            is a callable object to handle messages on that queue. Consumers will be
-            set up after each connection is established so they will survive networking
-            issues.
-    """
-
-    name = "fedora-messaging"
-    factoryClass = FedoraMessagingFactory
-
-    def __init__(
-        self, amqp_url=None, exchanges=None, queues=None, bindings=None, consumers=None
-    ):
-        """Initialize the service."""
-        service.MultiService.__init__(self)
-        amqp_url = amqp_url or config.conf["amqp_url"]
-        self._parameters = pika.URLParameters(amqp_url)
-        if amqp_url.startswith("amqps"):
-            _configure_tls_parameters(self._parameters)
-        if self._parameters.client_properties is None:
-            self._parameters.client_properties = config.conf["client_properties"]
-        self._exchanges = exchanges or []
-        self._queues = queues or []
-        self._bindings = bindings or []
-        self.factory = self.factoryClass(
-            self._parameters, exchanges=exchanges, queues=queues, bindings=bindings
-        )
-        consumers = consumers or {}
-        for queue, callback in consumers.items():
-            self.factory.consume(callback, queue)
-        warnings.warn(
-            "The FedoraMessagingService class is deprecated and will be removed"
-            " in fedora-messaging v2.0, please use FedoraMessagingServiceV2 instead.",
-            DeprecationWarning,
-        )
-
-    def startService(self):
-        self.connect()
-        service.MultiService.startService(self)
-
-    def stopService(self):
-        factory = self.getFactory()
-        if not factory:
-            return
-        factory.stopTrying()
-        service.MultiService.stopService(self)
-
-    def getFactory(self):
-        if self.services:
-            return self.services[0].factory
-        return None
-
-    def connect(self):
-        if self._parameters.ssl_options:
-            serv = SSLClient(
-                host=self._parameters.host,
-                port=self._parameters.port,
-                factory=self.factory,
-                contextFactory=_ssl_context_factory(self._parameters),
-            )
-        else:
-            serv = TCPClient(
-                host=self._parameters.host,
-                port=self._parameters.port,
-                factory=self.factory,
-            )
-        serv.factory = self.factory
-        name = "{}{}:{}".format(
-            "ssl:" if self._parameters.ssl_options else "",
-            self._parameters.host,
-            self._parameters.port,
-        )
-        serv.setName(name)
-        serv.setServiceParent(self)
-
-
 class FedoraMessagingServiceV2(service.MultiService):
     """
     A Twisted service to connect to the Fedora Messaging broker.
@@ -220,26 +124,28 @@ def _configure_tls_parameters(parameters):
     else:
         cert, key = None, None
 
-    ssl_context = ssl.create_default_context()
+    ssl_context = ssl.create_default_context(purpose=ssl.Purpose.SERVER_AUTH)
     if config.conf["tls"]["ca_cert"]:
         try:
             ssl_context.load_verify_locations(cafile=config.conf["tls"]["ca_cert"])
         except ssl.SSLError as e:
             raise exceptions.ConfigurationException(
-                'The "ca_cert" setting in the "tls" section is invalid ({})'.format(e)
+                f'The "ca_cert" setting in the "tls" section is invalid ({e})'
             )
-    ssl_context.options |= ssl.OP_NO_SSLv2
-    ssl_context.options |= ssl.OP_NO_SSLv3
-    ssl_context.options |= ssl.OP_NO_TLSv1
-    ssl_context.options |= ssl.OP_NO_TLSv1_1
-    ssl_context.verify_mode = ssl.CERT_REQUIRED
+    if sys.version_info >= (3, 7):
+        ssl_context.minimum_version = ssl.TLSVersion.TLSv1_2
+    else:
+        ssl_context.options |= ssl.OP_NO_SSLv2
+        ssl_context.options |= ssl.OP_NO_SSLv3
+        ssl_context.options |= ssl.OP_NO_TLSv1
+        ssl_context.options |= ssl.OP_NO_TLSv1_1
     ssl_context.check_hostname = True
     if cert and key:
         try:
             ssl_context.load_cert_chain(cert, key)
         except ssl.SSLError as e:
             raise exceptions.ConfigurationException(
-                'The "keyfile" setting in the "tls" section is invalid ({})'.format(e)
+                f'The "keyfile" setting in the "tls" section is invalid ({e})'
             )
     parameters.ssl_options = SSLOptions(ssl_context, server_hostname=parameters.host)
 
@@ -274,11 +180,6 @@ def _ssl_context_factory(parameters):
         client_cert = twisted_ssl.PrivateCertificate.loadPEM(client_keypair)
 
     hostname = parameters.host
-    if not isinstance(hostname, six.text_type):
-        # Twisted requires the hostname as decoded text, which it isn't in Python 2
-        # Decode with the system encoding since this came from the config file. Die,
-        # Python 2, die.
-        hostname = hostname.decode(locale.getdefaultlocale()[1])
     try:
         context_factory = twisted_ssl.optionsForClientTLS(
             hostname,
